summaryrefslogtreecommitdiffstats
path: root/libkdepim/komposer/core/editor.h
diff options
context:
space:
mode:
Diffstat (limited to 'libkdepim/komposer/core/editor.h')
-rw-r--r--libkdepim/komposer/core/editor.h16
1 files changed, 8 insertions, 8 deletions
diff --git a/libkdepim/komposer/core/editor.h b/libkdepim/komposer/core/editor.h
index 3b8d601a..a5b78915 100644
--- a/libkdepim/komposer/core/editor.h
+++ b/libkdepim/komposer/core/editor.h
@@ -25,7 +25,7 @@
#include "plugin.h"
-#include <qstringlist.h>
+#include <tqstringlist.h>
namespace KParts {
class Part;
@@ -50,14 +50,14 @@ namespace Komposer {
* This is the magic function that all derivatives have to reimplement.
* It returns the actual editor component.
*/
- virtual QWidget *widget() =0;
+ virtual TQWidget *widget() =0;
int supportedTextFormats() const;
/**
* Returns the full text inside the editor.
*/
- virtual QString text() const =0;
+ virtual TQString text() const =0;
/**
* This function is called when the plugin is selected by the user before the
@@ -66,7 +66,7 @@ namespace Komposer {
virtual void select();
/**
* Reimplement this method and return a @ref QStringList of all config
* modules your application part should offer via Komposer. Note that the
* part and the module will have to take care for config syncing themselves.
* Usually @p DCOP used for that purpose.
@@ -74,7 +74,7 @@ namespace Komposer {
* @note Make sure you offer the modules in the form:
* <code>"pathrelativetosettings/mysettings.desktop"</code>
*/
- virtual QStringList configModules() const { return QStringList(); }
+ virtual TQStringList configModules() const { return TQStringList(); }
public slots:
@@ -83,16 +83,16 @@ namespace Komposer {
* Most commonly used on replaying.
* If any text is present if will be deleted.
*/
- virtual void setText( const QString &txt ) =0;
+ virtual void setText( const TQString &txt ) =0;
/**
* Changes currently used signature. If no signature is present
* a new one should be appened.
*/
- virtual void changeSignature( const QString &txt ) =0;
+ virtual void changeSignature( const TQString &txt ) =0;
protected:
- Editor( QObject *parent, const char *name, const QStringList &args );
+ Editor( TQObject *parent, const char *name, const TQStringList &args );
private:
class Private;
@@ -66,7 +66,7 @@ namespace Komposer {
virtual void select();
/**
- * Reimplement this method and return a @ref QStringList of all config
+ * Reimplement this method and return a @ref TQStringList of all config
* modules your application part should offer via Komposer. Note that the
* part and the module will have to take care for config syncing themselves.